=================
Table of contents
=================

User's Guide
============

.. toctree::
   :maxdepth: 3

   usersguide


Reference manual
================

.. toctree::
    :maxdepth: 4

    apireference


Physics Guide
=============

.. toctree::
    :maxdepth: 4

    physicsguide

Developer's Guide
=================

.. toctree::
    :maxdepth: 4

    developer

Jupyter Tutorials
=================

.. toctree::
    :maxdepth: 4

   jupyter_tutorials